.. automodule:: brille
  :members:
  :undoc-members:
  :show-inheritance:

.. module:: brille._brille


Documented thus far:
^^^^^^^^^^^^^^^^^^^^
The pybind-wrapped objects fully documented (in C++ doc strings) thus far are

:py:class:`~brille._brille.Bravais`
:py:class:`~brille._brille.Lattice`

.. .. automodule:: brille._brille
..   :members:
..   :undoc-members:
..   :show-inheritance:

.. toctree::
  :maxdepth: 1
  :caption: Index

  module/lattice
  module/debug
  module/bz
  module/grids
  module/symmetry
  module/everything
